pub enum RepoCommand {
List,
Rm {
url: String,
},
}Variants
List
List canonical repos and how many live workspaces each has.
Rm
Delete a tool-managed clone (refuses for a discovered repo, or if it still has workspaces).