set_auto_clone

Function set_auto_clone 

pub fn set_auto_clone(path: &Path) -> Result<()>
Record a “always clone without asking” answer to the clone prompt. Prepended (rather than appended, like nothing else in this file does) because appending a bare key = value after one of config.toml’s [source.*] tables would parse as belonging to that table instead of to the top-level document.