pub struct WorkspaceDirty {
pub path: PathBuf,
}Expand description
Returned by remove_workspace when the workspace has local changes and force wasn’t set.
Callers should confirm with the user and retry with force: true if they agree to discard
them.
Fields
path: PathBufTrait Implementations
Sourceimpl Debug for WorkspaceDirty
impl Debug for WorkspaceDirty
Sourceimpl Display for WorkspaceDirty
impl Display for WorkspaceDirty
Sourceimpl Error for WorkspaceDirty
impl Error for WorkspaceDirty
1.30.0 · Sourcefn source(&self) -> Option<&(dyn Error + 'static)>
fn source(&self) -> Option<&(dyn Error + 'static)>
Returns the lower-level source of this error, if any. Read more
1.0.0 · Sourcefn description(&self) -> &str
fn description(&self) -> &str
👎Deprecated since 1.42.0:
use the Display impl or to_string()